@@ -1,3 +1,5 @@
+"""Oracle module messages."""
+
 from __future__ import annotations
 
 import copy
@@ -21,19 +23,48 @@ __all__ = [
 
 
 def vote_hash(denom: str, exchange_rate: Dec, salt: str, validator: str) -> str:
+    """Calculates vote hash for submitting :class:`MsgExchangeRatePrevote`.
+
+    Args:
+        denom (str): denom to vote for
+        exchange_rate (Dec): exchange rate of LUNA
+        salt (str): salt
+        validator (str): validator operator address
+
+    Returns:
+        str: vote hash
+    """
     payload = f"{denom}:{exchange_rate!s}:{salt}:{validator}"
     sha_hash = hashlib.sha256(payload.encode())
     return sha_hash.hexdigest()[:40]
 
 
-def aggregate_vote_hash(salt: str, exchange_rates: Coins, validator: str) -> str:
-    payload = f"{salt}:{exchange_rates!s}:{validator}"
+def aggregate_vote_hash(salt: str, exchange_rates: Coins.Input, validator: str) -> str:
+    """Calculates aggregate vote hash for submitting :class:`MsgAggregateExchangeRatePrevote`.
+
+    Args:
+        salt (str): salt
+        exchange_rates (Coins.Input): exchange rates in various denominations
+        validator (str): validator operator address
+
+    Returns:
+        str: aggregate vote hash
+    """
+    payload = f"{salt}:{str(Coins(exchange_rates))}:{validator}"
     sha_hash = hashlib.sha256(payload.encode())
     return sha_hash.hexdigest()[:40]
 
 
 @attr.s
 class MsgExchangeRatePrevote(Msg):
+    """Submit a prevote for the current vote period.
+
+    Args:
+        hash: vote hash
+        denom: denom for which the prevote is submitted
+        feeder: delegated feeder account submitting vote
+        validator: validator for which the prevote is submitted
+    """
 
     type = "oracle/MsgExchangeRatePrevote"
     action = "exchangerateprevote"
@@ -56,9 +87,20 @@ class MsgExchangeRatePrevote(Msg):
 
 @attr.s
 class MsgExchangeRateVote(Msg):
+    """Submit a vote for the current vote period.
+
+    Args:
+        exchange_rate (Dec): current exchange rate of LUNA
+        salt: salt for vote hash
+        denom: denom vote corresponds to
+        feeder: delegated feeder account submitting vote
+        validator: validator for which the vote is submitted
+    """
 
     type = "oracle/MsgExchangeRateVote"
+    """"""
     action = "exchangeratevote"
+    """"""
 
     exchange_rate: Dec = attr.ib(converter=Dec)
     salt: str = attr.ib()
@@ -78,9 +120,20 @@ class MsgExchangeRateVote(Msg):
         )
 
     def get_vote_hash(self) -> str:
+        """Vote hash required for the associated prevote.
+
+        Returns:
+            str: vote hash
+        """
         return vote_hash(self.denom, self.exchange_rate, self.salt, self.validator)
 
     def get_prevote(self) -> MsgExchangeRatePrevote:
+        """Generates the associated :class:`MsgExchangeRatePrevote` object with the
+        correct prepopulated fields.
+
+        Returns:
+            MsgExchangeRatePrevote: associated prevote
+        """
         return MsgExchangeRatePrevote(
             hash=self.get_vote_hash(),
             denom=self.denom,
@@ -91,9 +144,17 @@ class MsgExchangeRateVote(Msg):
 
 @attr.s
 class MsgDelegateFeedConsent(Msg):
+    """Re-assign oracle feeder account for a validator.
+
+    Args:
+        operator: validator to change feeder for
+        delegate: new feeder address
+    """
 
     type = "oracle/MsgDelegateFeedConsent"
+    """"""
     action = "delegatefeeder"
+    """"""
 
     operator: ValAddress = attr.ib()
     delegate: AccAddress = attr.ib()
@@ -106,8 +167,16 @@ class MsgDelegateFeedConsent(Msg):
 
 @attr.s
 class MsgAggregateExchangeRatePrevote(Msg):
+    """Submit an aggregate vote for the current vote period.
+
+    Args:
+        hash: aggregate vote hash
+        feeder: account submitting the aggregate prevote
+        validator: validator to which the aggregate prevote corresponds
+    """
 
     type = "oracle/MsgAggregateExchangeRatePrevote"
+    """"""
 
     hash: str = attr.ib()
     feeder: AccAddress = attr.ib()
@@ -125,8 +194,17 @@ class MsgAggregateExchangeRatePrevote(Msg):
 
 @attr.s
 class MsgAggregateExchangeRateVote(Msg):
+    """Submit an aggregate prevote for the current vote.
+
+    Args:
+        exchange_rates (Coins.Input): exchange rates to use
+        salt: aggregate vote salt
+        feeder: feeder account submitting aggregate prevote
+        validator: validator vote corresponds to
+    """
 
     type = "oracle/MsgAggregateExchangeRateVote"
+    """"""
 
     exchange_rates: Coins = attr.ib(converter=Coins)
     salt: str = attr.ib()
@@ -149,9 +227,20 @@ class MsgAggregateExchangeRateVote(Msg):
         )
 
     def get_aggregate_vote_hash(self) -> str:
+        """Vote hash required for message's associated prevote.
+
+        Returns:
+            str: aggregate vote hash
+        """
         return aggregate_vote_hash(self.salt, self.exchange_rates, self.validator)
 
     def get_aggregate_prevote(self) -> MsgAggregateExchangeRatePrevote:
+        """Generates the associated :class:`MsgAggregateExchangeRatePrevote` object with
+        the correct prepopulated fields.
+
+        Returns:
+            MsgAggregateExchangeRatePrevote: associated aggregate prevote
+        """
         return MsgAggregateExchangeRatePrevote(
             hash=self.get_aggregate_vote_hash(),
             feeder=self.feeder,
